// Basic character controller script
// Provided as part of 3D World tutorial by Okan Arikan on using Animeeple 

// Variables
var walkSpeed : float;
var runSpeed : float;
private var controller : CharacterController;
private var speed : float = 0;
private var moveDirection : Vector3 = Vector3.zero;

function Start() {
    // Init variables
    controller = GetComponent(CharacterController);
    
    // Tell all animations to loop, except the punchinging animation
    // which should only play once
    animation.wrapMode = WrapMode.Loop;
    animation["Punch"].wrapMode = WrapMode.Clamp;

    // Give the punch animation a higher priority
    // The default is 0
    animation["Punch"].layer = 1;

    // Stop all animations
    animation.Stop();
}

function Update () {
    // Playback walk or idle depending
    // on whether the player is moving
    if ((Mathf.Abs(Input.GetAxis("Vertical")) > 0.2) || (Mathf.Abs(Input.GetAxis("Horizontal")) > 0.2)) {
        
        // Are we walking or running?
        if(Input.GetButton("Run")) {
            // Running
            animation.CrossFade("Run");

            // Are we running forwards or backwards?
            // Set the speed of the animation playback
            animation["Run"].speed = (Input.GetAxis("Vertical") < -0.2) ? -1 : 1;

            // Set the speed of the character's root 
            // We use the absolute value of the vertical input axis here
            // because we'll take into account direction when we compute
            // the moveDirection
            speed = Mathf.Abs(Input.GetAxis("Vertical")) * runSpeed;
        } else {
            // Walking
            animation.CrossFade("Walk");

            // Are we walking forwards or backwards?
            // Set the speed of the animation playback
            animation["Walk"].speed = (Input.GetAxis("Vertical") < -0.2) ? -1 : 1;

            // Set the speed of the character's root
            speed = Mathf.Abs(Input.GetAxis("Vertical")) * walkSpeed;
        }
    } else {
        animation.CrossFade("Idle");
        speed = 0;
    }

    // Play the punch animation
    if (Input.GetButtonDown("Punch"))
        // Use CrossFadeQueued here instead of CrossFade so that if the player presses the "Punch" button twice quickly,
        // the player punches twice instead of once.  CrossFadeQueued duplicates the animation state, making it possible
        // to fade between the same animation.
        animation.CrossFadeQueued("Punch");

    // If the punch animation is playing, the root should not be moving
    if (animation.IsPlaying("Punch"))
        speed = 0;

    // Detect horizontal input and rotate the character
    transform.eulerAngles.y += Input.GetAxis("Horizontal");

    // Input.GetAxis("Vertical") returns a positive number if we're pressing the up arrow, and
    // a negative number if we're pressing the down arrow. So our moveDirection will either be
    // (0,0,0) for idle, or (0,0,+/-) for walking.
    moveDirection = Vector3(0,0,Input.GetAxis("Vertical"));

    // We need to multiply the direction we're moving by the character's transform so that
    // we move correctly in world space.
    moveDirection = transform.TransformDirection(moveDirection);

    // Finally, move the controller. Time.deltaTime gives us the elapsed time since
    // Update was last called. Multiplying Time.deltaTime with speed will give us
    // the distance the character should have traveled since the last frame. We
    // scale the moveDirection by this distance.
    controller.Move(moveDirection * (Time.deltaTime * speed));
}